@@ -140,8 +140,12 @@ class LessThanFilter(logging.Filter):
 
 
 class BufferingSMTPHandler(logging.Handler):
+    ENCRYPTION_STARTTLS = "starttls"
+    ENCRYPTION_TLS = "tls"
+
     credentials = None
-    secure = False
+    encryption = None
+    secure = False  # = starttls backward compatibility
     timeout = 5.0
 
     timer = None
@@ -230,11 +234,18 @@ class BufferingSMTPHandler(logging.Handler):
         message.set_content("\n".join(content))
 
         host, port = self.get_host_port()
-        smtp = smtplib.SMTP(host, port, timeout=self.timeout)
 
-        if self.secure:
-            smtp.starttls()
-            smtp.ehlo()
+        if self.encryption == self.ENCRYPTION_TLS:
+            if port is None:
+                port = smtplib.SMTP_SSL_PORT
+            smtp = smtplib.SMTP_SSL(host, port, timeout=self.timeout)
+        else:
+            if port is None:
+                port = smtplib.SMTP_PORT
+            smtp = smtplib.SMTP(host, port, timeout=self.timeout)
+
+            if self.encryption == self.ENCRYPTION_STARTTLS or self.secure:
+                smtp.starttls()
 
         username, password = self.get_credentials()
         if username is not None:
@@ -252,7 +263,7 @@ class BufferingSMTPHandler(logging.Handler):
     def get_host_port(self):
         if isinstance(self.host, (list, tuple)):
             return self.host
-        return self.host, smtplib.SMTP_PORT
+        return self.host, None
 
     def get_credentials(self):
         if isinstance(self.credentials, (list, tuple)):
